/**
  *  \file client/dlg-tax.h
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_DLG_TAX_H
#define PCC_V2_CLIENT_DLG_TAX_H

#include "game/planet.h"
#include "cpluslib/holder.h"
#include "ui/widgets/numbersel.h"
#include "ui/window.h"
#include "game/planetpred.h"

class WColonistTaxSelector : public UINumberSelector {
    int      old_value;
    int      mifa;
    GPlanet& planet;
    GPlanetEffectors eff;
 public:
    WColonistTaxSelector(int id, GPlanet& planet, int mifa);
    void  doAutoTax();
    bool  handleEvent(const UIEvent& e, bool second_pass);
    void  drawContent(GfxCanvas& can);
    void  getLayoutInfo(LayoutInfo& info);
    void  commit();
    void  cancel();
    void  setEffectors(GPlanetEffectors eff)
        { this->eff = eff; drawWidget(); }
};

class WNativeTaxSelector : public UINumberSelector {
    int      old_value;
    int      mifa;
    GPlanet& planet;
    UINumberSelector& colonist_tax;
    GPlanetEffectors eff;
 public:
    WNativeTaxSelector(int id, GPlanet& planet, int mifa, UINumberSelector& colos);
    void  doAutoTax();
    bool  handleEvent(const UIEvent& e, bool second_pass);
    void  drawContent(GfxCanvas& can);
    void  getLayoutInfo(LayoutInfo& info);
    void  commit();
    void  cancel();
    void  setEffectors(GPlanetEffectors eff)
        { this->eff = eff; drawWidget(); }
};

class WPlanetGrowthTile;

class WTaxationDialog : public UIWindow {
    ObjectHolder          h;
    GPlanet&              planet;
    WColonistTaxSelector  ctax;
    WNativeTaxSelector*   p_ntax;
    WPlanetGrowthTile*    p_growth;

    GPlanetEffectors eff;
    Signal1<GPlanetEffectors> sig_eff;

    void init(int mi, int fa);
    void redrawNatives(int);
    void commit();
    void cancel();
    void doAutoTax();
    void onChange();
    void editEffectors();
 public:
    WTaxationDialog(GPlanet& planet, int mi, int fa);
    ~WTaxationDialog();

    bool handleEvent(const UIEvent& e, bool second_pass);
};

void doTaxation(GPlanet& p);
void doTaxation(GPlanet& p, int mi, int fa);

#endif
