/**
  *  \file client/widgets/selswitch.cc
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/selswitch.h"
#include "game/sel.h"
#include "game/global.h"
#include "client/widgets/decaymsg.h"
#include "cpluslib/format.h"
#include "util/nls.h"

static void
doSwitch(int delta)
{
    /* Figure out new layer */
    int newLayer = GMultiSelection::getCurrentSelectionLayer();
    newLayer += GMultiSelection::NUM_SELECTION_LAYERS;
    newLayer += delta;
    newLayer %= GMultiSelection::NUM_SELECTION_LAYERS;

    /* Switch to new layer */
    GMultiSelection::setCurrentSelectionLayer(newLayer);
    getDisplayedTurn().getCurrentUniverse().doScreenUpdates();

    /* Display hint */
    showDecayingMessage(format(_("Selection %c"), 'A' + newLayer));
}

WSelectionSwitcher::WSelectionSwitcher()
{
    /* We don't want focus */
    setState(st_Disabled, true);
}

WSelectionSwitcher::~WSelectionSwitcher()
{ }

bool
WSelectionSwitcher::handleEvent(const UIEvent& event, bool second_pass)
{
    if (event.type == ev_Key) {
        if (event.key.code == SDLK_LEFT + ss_Alt) {
            doSwitch(-1);
            return true;
        }
        if (event.key.code == SDLK_RIGHT + ss_Alt) {
            doSwitch(+1);
            return true;
        }
    }
    return UIFixedWidget::handleEvent(event, second_pass);
}

void
WSelectionSwitcher::drawContent(GfxCanvas& /*can*/)
{ }
