/**
  *  \file game/attachmentconfiguration.cc
  *  \brief Attachment Configuration
  */

#include "game/attachmentconfiguration.h"
#include "util/conf.h"
#include "game/pref.h"
#include "game/attachmentunpacker.h"


namespace {
    // FIXME: for a configuration GUI, these values would need to be exported somehow
    const int ASK = 0, ACCEPT = 1, REJECT = 2;
    ValueEnumParser TriboolParser("ask,accept,reject");

    ConfigIntOption Unpack_AcceptRaceNames(getUserPreferences(), "Unpack.RaceNames", TriboolParser);
    ConfigStringOption Unpack_AttachmentTimestamp(getUserPreferences(), "Unpack.AttachmentTimestamp");
}

bool
checkNewAttachments(GAttachmentUnpacker& unpacker)
{
    // Do we have any attachments? (Should not call getTimestamp() without attachments.)
    // If we don't proceed with saving (which will be a no-op).
    if (unpacker.getNumAttachments() == 0) {
        return true;
    }

    // Check timestamp
    // If we already saw these attachments, deselect all and proceed with saving (which will be a no-op).
    if (unpacker.getTimestamp().getTimestampAsString() == Unpack_AttachmentTimestamp()) {
        unpacker.selectAllAttachments(false);
        return true;
    }

    // Check attachment types
    GAttachmentUnpacker::Kinds_t kinds = unpacker.getAllAttachmentKinds();

    // Reject CriticalFiles
    kinds -= GAttachmentUnpacker::CriticalFile;
    unpacker.selectAttachmentsByKind(GAttachmentUnpacker::CriticalFile, false);

    // Deal with race names
    int raceNames = Unpack_AcceptRaceNames();
    if (raceNames != ASK) {
        kinds -= GAttachmentUnpacker::RaceNameFile;
        unpacker.selectAttachmentsByKind(GAttachmentUnpacker::RaceNameFile, (raceNames == ACCEPT));
    }

    // If any attachments remain, let the user decide.
    // If no undecided attachment remains, proceed with saving.
    return kinds.empty();
}

void
markAttachmentsProcessed(const GAttachmentUnpacker& unpacker)
{
    if (unpacker.getNumAttachments() != 0) {
        ConfigStringOption& opt = Unpack_AttachmentTimestamp;
        opt.set(unpacker.getTimestamp().getTimestampAsString());
        opt.setSource(ConfigOption::srcGame);
    }
}
