/**
  *  \file game/attachmentconfiguration.h
  *  \brief Attachment Configuration
  */
#ifndef PCC_V2_GAME_ATTACHMENTCONFIGURATION_H
#define PCC_V2_GAME_ATTACHMENTCONFIGURATION_H

class GAttachmentUnpacker;

/** Check for new attachments.
    Call after loading all attachments into an AttachmentUnpacker.

    \param unpacker Unpacker

    \retval true  AttachmentUnpacker has been configured; call unpacker.saveFiles() next
    \retval false Offer user selection of attachments, then possibly call unpacker.saveFiles()

    Note: after unpacker.saveFiles(), call markAttachmentsProcessed(). */
bool checkNewAttachments(GAttachmentUnpacker& unpacker);

/** Mark attachments processed.
    Call after unpacker.saveFiles().
    Do NOT call dropUnselectedAttachments() before calling this function.

    This updates the user configuration object to remember that these attachments were processed
    (regardless whether user chose to save or skip them).

    \param unpacker Unpacker */
void markAttachmentsProcessed(const GAttachmentUnpacker& unpacker);

#endif
