/**
  *  \file io/memdir.h
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_IO_MEMDIR_H
#define PCC_V2_IO_MEMDIR_H

#include <map>
#include "io/dirs.h"
#include "cpluslib/string.h"
#include "cpluslib/smartptr.h"
#include "io/memstream.h"

class MemoryDirectory : public Directory {
    string_t name;

    typedef std::map<string_t,Ptr<MemoryStream> > container_t;

    container_t content;

    class Entry;
    class Enum;
    friend class Entry;
    friend class Enum;

    MemoryDirectory(string_t name);
 public:
    static Ptr<MemoryDirectory> create(string_t name);
    ~MemoryDirectory();

    /* Directory methods */
    Ptr<DirectoryEntry> getEntryByName(string_t name);
    Ptr<Enumeration<Ptr<DirectoryEntry> > > getEntries();
    Ptr<Directory> getParent();
    string_t getName();

    /* MemoryDirectory methods */
    Ptr<MemoryStream> getStreamByName(string_t name, bool create_flag);
    bool eraseStream(string_t name);
    bool renameStream(string_t oldname, string_t newname);
};

#endif
